@@ -3,7 +3,7 @@ package App::MysqlUtils;
 ## no critic (InputOutput::RequireBriefOpen)
 
 our $DATE = '2018-11-06'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -385,24 +385,28 @@ $SPEC{mysql_sql_dump_extract_tables} = {
             'x.name.singular' => 'include_table',
             schema => ['array*', of=>'str*'],
             tags => ['category:filtering'],
+            cmdline_aliases => {I=>{}},
         },
         exclude_tables => {
             'x.name.is_plural' => 1,
             'x.name.singular' => 'exclude_table',
             schema => ['array*', of=>'str*'],
             tags => ['category:filtering'],
+            cmdline_aliases => {X=>{}},
         },
         include_table_patterns => {
             'x.name.is_plural' => 1,
             'x.name.singular' => 'include_table_pattern',
             schema => ['array*', of=>'re*'],
             tags => ['category:filtering'],
+            cmdline_aliases => {pat=>{}},
         },
         exclude_table_patterns => {
             'x.name.is_plural' => 1,
             'x.name.singular' => 'exclude_table_pattern',
             schema => ['array*', of=>'re*'],
             tags => ['category:filtering'],
+            cmdline_aliases => {xpat=>{}},
         },
         stop_after_table => {
             schema => 'str*',
@@ -647,7 +651,7 @@ App::MysqlUtils - CLI utilities related to MySQL
 
 =head1 VERSION
 
-This document describes version 0.011 of App::MysqlUtils (from Perl distribution App-MysqlUtils), released on 2018-11-06.
+This document describes version 0.012 of App::MysqlUtils (from Perl distribution App-MysqlUtils), released on 2018-11-06.
 
 =head1 SYNOPSIS
 
